==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QWizard_shell.h <==
#ifndef QWIZARD_SHELL_H
#define QWIZARD_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(wizard)
#include <QtWidgets/qwizard.h>
#endif //QT_CONFIG(wizard)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#if QT_CONFIG(abstractbutton)
#include <QtWidgets/qabstractbutton.h>
#endif //QT_CONFIG(abstractbutton)
#include <QtWidgets/qaction.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(wizard)

class QWizard_shell : public QWizard, public QtJambiShellInterface
{
public:
    QWizard_shell(QWidget* parent0 = nullptr, Qt::WindowFlags flags1 = Qt::WindowFlags());
    ~QWizard_shell() override;

    void accept() override;
    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void cleanupPage(int id0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void done(int result0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    int exec() override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initializePage(int id0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    int nextId() const override;
    void open() override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reject() override;
    void resizeEvent(QResizeEvent* event0) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool validateCurrentPage() override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWizard_access : public QWizard
{
    void __qt_cleanupPage_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0);
    void __qt_done_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint result0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_initializePage_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0);
    jint __qt_nextId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_setVisible_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean visible0);
    jobject __qt_sizeHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_validateCurrentPage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(wizard)
#endif // QWIZARD_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QWizard_shell.h <==
#ifndef QWIZARD_SHELL_H
#define QWIZARD_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(wizard)
#include <QtWidgets/qwizard.h>
#endif //QT_CONFIG(wizard)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#if QT_CONFIG(abstractbutton)
#include <QtWidgets/qabstractbutton.h>
#endif //QT_CONFIG(abstractbutton)
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(wizard)

class QWizard_shell : public QWizard, public QtJambiShellInterface
{
public:
    QWizard_shell(QWidget* parent0 = nullptr, Qt::WindowFlags flags1 = Qt::WindowFlags());
    ~QWizard_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QWizard_mshell;
    friend class QWizard_oshell;
};


class QWizard_mshell : public QWizard_shell
{
public:
    using QWizard_shell::QWizard_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QWizard_oshell : public QWizard_mshell
{
public:
    using QWizard_mshell::QWizard_mshell;
    ~QWizard_oshell() override;
    void accept() override;
    void actionEvent(QActionEvent* event0) override;
    void changeEvent(QEvent* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void cleanupPage(int id0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* arg__1) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void done(int result0) override;
    void dragEnterEvent(QDragEnterEvent* event0) override;
    void dragLeaveEvent(QDragLeaveEvent* event0) override;
    void dragMoveEvent(QDragMoveEvent* event0) override;
    void dropEvent(QDropEvent* event0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    int exec() override;
    void focusInEvent(QFocusEvent* event0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* event0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initializePage(int id0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery arg__1) const override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void leaveEvent(QEvent* event0) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void moveEvent(QMoveEvent* event0) override;
    int nextId() const override;
    void open() override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* event0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reject() override;
    void resizeEvent(QResizeEvent* event0) override;
    void setVisible(bool visible0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* event0) override;
    bool validateCurrentPage() override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWizard_access : public QWizard
{
    void __qt_cleanupPage_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0);
    void __qt_done_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint result0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_initializePage_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0);
    jint __qt_nextId_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    void __qt_setVisible_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean visible0);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_validateCurrentPage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(wizard)
#endif // QWIZARD_SHELL_H
